package Time::DayOfYear;

use 5.008;
use strict;
use warnings;

require Exporter;

our @ISA = qw(Exporter);

# Items to export into callers namespace by default. Note: do not export
# names by default without a very good reason. Use EXPORT_OK instead.
# Do not simply export all your public functions/methods/constants.

# This allows declaration	use Time::DayOfYear ':all';
# If you do not need this, moving things directly into @EXPORT or @EXPORT_OK
# will save memory.
our %EXPORT_TAGS = ( 'all' => [ qw(
ydoy2md ymd2doy	
) ] );

our @EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} } );

our @EXPORT = qw(
ydoy2md ymd2doy	
);

our $VERSION = '0.01';

our @dtab = ( [0,0,31,59,90,120,151,181,212,243,273,304,334],
	      [0,0,31,60,91,121,152,182,213,244,274,305,335] );

# Preloaded methods go here.
# Preloaded methods go here.
sub ymd2doy
{
	my ($year, $month, $day) = @_;
	return $dtab[is_leap_year($year)][$month]+$day;
}

sub ydoy2md
{
	my ($year, $day_of_year) = @_;
	my @days = grep { $_ > 0 } map { $day_of_year - $_ } @{$dtab[is_leap_year($year)]};
	return ( $#days, $days[-1] );
}

sub is_leap_year
{
	my ($year) = @_;
	return 0 unless $year % 4 == 0;
	return 1 unless $year % 100 == 0;
	return 0 unless $year % 400 == 0;
	return 1;
}

1;
__END__
# Below is stub documentation for your module. You'd better edit it!

=head1 NAME

Time::DayOfYear -- convert between (Month,Day) and (Day_of_Year) date formats.

=head1 SYNOPSIS

	use Time::DayOfYear;

	($month_1_to_12, $day_of_month_1_to_31) = ydoy2md($four_digit_year, $day_of_year_1_to_366);
	$day_of_year_1_to_366 = ymd2doy($four_digit_year, $month_1_to_12, $day_of_month_1_to_31);

=head1 DESCRIPTION

DayOfYear converts between (Month,Day) and (Day_of_Year) date formats.
Years should be expressed with four digits: 1998, not 98.
Beware! Input variables are not checked to be valid.

=head1 AUTHOR

Robert Cameron <rcameron@cfa.harvard.edu>

=cut
