# --8<--8<--8<--8<--
#
# Copyright (C) 2006 Smithsonian Astrophysical Observatory
#
# This file is part of yaxx
#
# yaxx is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# yaxx is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the 
#       Free Software Foundation, Inc. 
#       51 Franklin Street, Fifth Floor
#       Boston, MA  02110-1301, USA
#
# -->8-->8-->8-->8--

use strict;
use warnings;

##****************************************************************************
sub DMcoord_open {
#
# Create/modify a package level dmcoords object for this obsid.
# Do this on a per-obsid basis (instead of per-source) for efficiency reasons
#
##****************************************************************************
    my $self = shift;

    if (not defined $YaxxSource::DMcoord or $self->obsid != $YaxxSource::DMcoord_obsid) {
	eval { $YaxxSource::DMcoord = Chandra::Tools::dmcoords->new( $self->file('obsid_evt2') ) };
	if (not defined $YaxxSource::DMcoord or $@) {
	    message("ERROR - Could not start dmcoords for ", $self->file('obsid_evt2'));
	    message("        dmcoords error $@") if $@;
	    confess $YaxxSource::FATAL_ERROR;
	}
	$YaxxSource::DMcoord_obsid = $self->obsid;
    }
    return 1;
}
	    
##****************************************************************************
sub DMcoord_coords {
#
# Call dmcoord->coords, using DMcoord_open to ensure that the current package
# variable $DMcoord is for the correct obsid
#
##****************************************************************************
    my $self = shift;

    # Make sure an appropriate instance of dmcoords is running
    $self->DMcoord_open();	
    return $YaxxSource::DMcoord->coords(@_);
}
	    
##****************************************************************************
sub DMcoord_set {
#
# Call dmcoord->set, using DMcoord_open to ensure that the current package
# variable $DMcoord is for the correct obsid
#
##****************************************************************************
    my $self = shift;

    # Make sure an appropriate instance of dmcoords is running
    $self->DMcoord_open();	
    return $YaxxSource::DMcoord->set(@_);
}
	    
1;
