# --8<--8<--8<--8<--
#
# Copyright (C) 2006 Smithsonian Astrophysical Observatory
#
# This file is part of yaxx
#
# yaxx is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# yaxx is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the 
#       Free Software Foundation, Inc. 
#       51 Franklin Street, Fifth Floor
#       Boston, MA  02110-1301, USA
#
# -->8-->8-->8-->8--

use strict;
use warnings;

##****************************************************************************
sub make_fakes {
# 
# Make new (derived) datasets
#
##****************************************************************************
    my $self = shift;
    my $n_fake = shift;
    my $fake;
    my %cols = (copy => [qw(pi)],
		make_local_copy => [qw(src bkg rmf arf
				       bg_pi bg_rmf bg_arf asphist source_image)]);
    local $_;

    croak "Error - need to set process_fake=1 in config file for fake data\n"
      unless ($self->process_fake);

    # Go to base directory
    local $CWD = $self->analysis_dir;

    # return if src or obs should be ignored
    return 1 if (-e $self->file('ignore_src') or -e $self->file('ignore_obs'));

    foreach my $fakeid (1 .. $n_fake) {
	# Make a fake source corresponding to the real source 
	#  Make directories in fake source, and then copy pi rmf arf files 
	#  as well as correct MDL file

	$fake = YaxxSource->($self, {fakeid => $fakeid});

	message("Create fake files in " . $fake->file('src_dir') . "\n");

	# (This should really be a true dependence test...)
	next if (-e $fake->file('pi', {ext => '.gz'}) or -e $fake->file('pi'));;	# Skip if already faked

	# Initialize data directories and data as for a normal source
	$fake->make_dirs();
	$fake->gunzip();
	$fake->clean($self->force);
	$fake->clean($self->preclean);
	$fake->get_data_files();

	# (SHOULD ALSO copy mdl files, but this needs globbing or special treatment)
	foreach my $op (keys %cols) {
	    foreach (@{$cols{$op}}) {
		my $fake_file = $fake->file($_);
		my $real_file = $self->file($_);

		if (-e $real_file) {
		    if (-e $fake_file) {
			message("make_fakes: Warning - $fake_file already exists, skipping\n");
			next;
		    }
		    &{$op}($real_file, $fake_file);
		}
	    }
	}

	# Now finally run the thing which generates fake data
	if ($fake->{fake_program}) {
	    #   local $CWD = $self->CWD; # Go to user directory from which yaxx was called
	    my $fake_program = $fake->customize_string($fake->{fake_program});
	    message("Running $fake_program\n");
	    system($fake_program);
	}

	# .. and make the grouped (binned) file
	$fake->set_pi_info();
	$fake->group_pi_file();

    } continue {
	$fake->gzip();
    }

    1;
}

#********************************************************************************
# Go to next instance if this is a fake dataset
# Check if it exists by looking for pi file.  (Always succeeds for fakeid==0,
# which is the 'real' dataset)
sub next_instance {
#********************************************************************************
    my $self = shift;

    # Go to next fake dataset, or to the real dataset (fakeid==0) if this is the
    # first request for the 'next instance'
    $self->fakeid( defined $self->fakeid ? $self->fakeid + 1 : 0 );

    # Return true (implying data for this fakeid are available) if
    # fakeid==0 is the real data, so it is always there.
    # If fakeid > 0, this is fake data, so check that it exists and
    # that processing of fake data is allowed
   return ($self->fakeid == 0
	    or ($self->process_fake && -d dirname($self->file('pi')))
	   );
}

1;
