# --8<--8<--8<--8<--
#
# Copyright (C) 2006 Smithsonian Astrophysical Observatory
#
# This file is part of yaxx
#
# yaxx is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# yaxx is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the 
#       Free Software Foundation, Inc. 
#       51 Franklin Street, Fifth Floor
#       Boston, MA  02110-1301, USA
#
# -->8-->8-->8-->8--

use strict;
use warnings;

##****************************************************************************
sub group_pi_file {
##****************************************************************************
    my $self = shift;
    local $_;

    my $pi = $self->file('pi');
    my $pi_bin = $self->file('pi_bin');
    my @test_dep = (-target => $pi_bin, -depend => $pi);
    my $bin_size = sprintf "%d", $self->counts / $self->max_bins;
    $bin_size = $self->bin_counts if $bin_size < $self->bin_counts;
    
    return 1 unless test_dep(@test_dep);

    my $tabspec = get_tabspec($self->file('rmf'), $self->min_energy, $self->max_energy);

    unlink $pi_bin if (-e $pi_bin);
    run_tool("dmgroup",
	     infile => $pi,     # Input datafile specification
	     outfile => $pi_bin, # Output datafile specification
	     grouptype => 'NUM_CTS', #          Grouping type
	     grouptypeval => $bin_size, #  Grouping type value
	     binspec => '""',	#        Binning specification (file or list)
	     tabspec => "'$tabspec'", # Ignore rows 
	     tabcolumn => $self->spec_chan_type,	# Column for ignoring rows
	     xcolumn => $self->spec_chan_type,	#          Name of column to bin on
	     ycolumn => 'COUNTS', #          Name of column to bin on
	     {
	      loud => 1,
	      timeout => $self->timeout,
	      paste => 1,
	     }
	    );

    if (test_dep(@test_dep)) {
	message("ERROR - did not create all files in dmgroup\n");
	return;
    }

    1;
}


##****************************************************************************
sub get_tabspec {
##****************************************************************************
    my $rmf = shift;
    my $min_energy = shift;
    my $max_energy = shift;
    local $_;

    my %rmf = fits_read_bintbl($rmf, {extname => 'EBOUNDS'});
    my $ok = PDL::which($rmf{e_min} > $min_energy/1000);
    my $min_spec = ($ok->nelem > 0) ? sprintf("1:%d:#1", $ok->at(0)+1) : '';
    $ok = PDL::which($rmf{e_max} < $max_energy/1000);
    my $max_spec = ($ok->nelem > 0) ? sprintf("%d::#1", $ok->at(-1)+1) : '';

#  The following applies if dmgroup works properly.  Currently (CIAO 3.2) only one tabspec
#  can be given at once
#    return join(',', $min_spec, $max_spec);

    return $min_spec;
}

1;
